| UKDNA17freqs | R Documentation |
A dataset containing allele frequencies for 16 autosomal STR loci from the
UK Population dataset. Frequencies are provided for four
population groups: "White_-_EA1_&_EA2",
"Black_African_&_Caribbean_-_EA3", "Indian_-_EA4" and
"Chinese_-_EA5".
UKDNA17freqs
A named list of length 4.
Each element is itself a named list of 16 STR loci, with named numeric vectors of allele frequencies.
Each population group is a named list of 16 elements, where each element
corresponds to a specific STR locus (e.g., D3S1358, vWA,
FGA, etc.).
Each locus is represented as a named numeric vector:
Names: allele values (as character strings, e.g., "12", "14.2")
Values: allele frequencies for that population group
An attribute "N" is attached to each population list, specifying the
sample size (number of alleles) for each locus.
Raw data on which the data set is based is available from https://www.gov.uk/government/statistics/dna-population-data-to-support-the-implementation-of-national-dna-database-dna-17-profiling under the Open Government licence https://www.nationalarchives.gov.uk/doc/open-government-licence/version/3/
# Access allele frequencies for D3S1358 in the Indian_-_EA4 population
UKDNA17freqs$`Indian_-_EA4`$D3S1358
# Frequency of allele "15" at D3S1358 in the Indian_-_EA4 population
UKDNA17freqs$`Indian_-_EA4`$D3S1358["15"]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.